package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.DkFj;

/**
 * 贷款_附件Mapper接口
 * 
 * @author boman
 * @date 2023-06-15
 */
public interface DkFjMapper 
{
    /**
     * 查询贷款_附件
     * 
     * @param id 贷款_附件主键
     * @return 贷款_附件
     */
    public DkFj selectDkFjById(Long id);

    /**
     * 查询贷款_附件列表
     * 
     * @param dkFj 贷款_附件
     * @return 贷款_附件集合
     */
    public List<DkFj> selectDkFjList(DkFj dkFj);

    /**
     * 新增贷款_附件
     * 
     * @param dkFj 贷款_附件
     * @return 结果
     */
    public int insertDkFj(DkFj dkFj);

    /**
     * 修改贷款_附件
     * 
     * @param dkFj 贷款_附件
     * @return 结果
     */
    public int updateDkFj(DkFj dkFj);

    /**
     * 删除贷款_附件
     * 
     * @param id 贷款_附件主键
     * @return 结果
     */
    public int deleteDkFjById(Long id);

    /**
     * 批量删除贷款_附件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDkFjByIds(Long[] ids);
}
